<template>
    <section class="games">
        <GameSwitch page="bubbles" />
        <div class="games__row">
            <div class="bubbles">
                <div class="input__row">
                    <div class="input-item">
                        <label for="sum" class="bubbles__label">Сумма</label>
                        <div class="bubbles__group">
                            <input 
                                class="bubbles__amount" 
                                type="number" 
                                min="1" 
                                max="99999" 
                                step="1" 
                                v-model="amount" 
                                @change="validateBet"
                            />
                            <button type="button" class="bubbles__btn" @click="typeBet('min')">
                                Min
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeBet('max')">
                                Max
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeBet('x2')">
                                X2
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeBet('/2')">
                                /2
                            </button>
                        </div>
                    </div>
                    <div class="input-item">
                        <label for="sum" class="bubbles__label">Цель</label>
                        <div class="bubbles__group">
                            <input 
                                class="bubbles__amount" 
                                type="number" 
                                min="1" 
                                max="99999" 
                                step="1" 
                                v-model="goal" 
                                @keypress="updateResult('goal')"
                                @keyup="updateResult('goal')"
                                @change="validateGoal"
                            />
                            <button type="button" class="bubbles__btn" @click="typeGoal('min')">
                                Min
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeGoal('max')">
                                Max
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeGoal('x2')">
                                X2
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeGoal('/2')">
                                /2
                            </button>
                        </div>
                    </div>
                    <div class="input-item">
                        <label for="sum" class="bubbles__label">Шанс</label>
                        <div class="bubbles__group">
                            <input 
                                class="bubbles__amount" 
                                type="number" 
                                min="1" 
                                max="99999" 
                                step="1" 
                                v-model="chance" 
                                @keypress="updateResult('chance')"
                                @keyup="updateResult('chance')"
                                @change="validateChance"
                            />
                            <button type="button" class="bubbles__btn" @click="typeChance('min')">
                                Min
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeChance('max')">
                                Max
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeChance('x2')">
                                X2
                            </button>
                            <button type="button" class="bubbles__btn" @click="typeChance('/2')">
                                /2
                            </button>
                        </div>
                    </div>
                </div>
                <div class="result__row mt-default">
                    <div class="result-item flex-30">
                        <button 
                            class="btn bubbles__btn-range" 
                            :disabled="game.loading"
                            @click="createBet"
                        >
                            Играть
                            <img
                                class="btn-icon"
                                src="/assets/img/icon/play-bubbles.svg"
                            />
                        </button>
                    </div>
                    <div class="result-item flex-65">
                        <button 
                            :class="[
                                'btn text-coeff',
                                { 'bubbles__btn-success': game.status == 'success' },
                                { 'bubbles__btn-danger': game.status == 'danger' }
                            ]"
                            v-if="game.text !== null"
                        >
                            {{ game.text }}
                        </button>
                        <div class="cssload-loader m-auto" v-if="game.loading">
                            <div class="cssload-inner cssload-one"></div>
                            <div class="cssload-inner cssload-two"></div>
                            <div class="cssload-inner cssload-three"></div>
                        </div>
                    </div>
                </div>
            </div>
            <History />
        </div>
    </section>
</template>

<script>
import GameSwitch from '../components/GameSwitch'
import History from '../components/History'

export default {
    components: {
        GameSwitch,
        History,
    },
    data () {
        return {
            amount: 1,
            chance: 50,
            goal: 2,
            game: {
                status: null,
                text: null,
                loading: false
            }
        }
    },
    mounted() {
        this.validateBet();
        this.validateChance();
        this.validateGoal();
    },
    methods: {
        createBet() {
            this.game.text = null;
            this.game.loading = true;
            this.$root.axios.post('/bubbles/play', {
                amount: this.amount,
                chance: this.chance
            })
            .then(response => {
                const { data } = response;
                this.game.loading = false;
                
                if(data.error) {
                    this.game.status = 'danger';
                    this.game.text = data.message;
                    return;
                }

                this.game.status = data.result
                    ? 'success'
                    : 'danger';
                this.game.text = data.result
                    ? `X${parseFloat(data.multiplier).toFixed(2)} | Выигрыш: ${parseFloat(data.total).toFixed(2)}`
                    : `X${parseFloat(data.multiplier).toFixed(2)}`;
                    
                this.$root.user.balance = data.balance;
            })
            .catch(error => {
                this.game.loading = false;
                this.game.status = 'danger';
                this.game.text = error.response.data.message;
            })
        },
        updateResult(type) {
            switch(type) {
                case 'goal':
                    this.chance = 100/this.goal;
                    this.validateChance()
                break;
                case 'chance':
                    this.goal = 100/this.chance;
                    this.validateGoal()
                break;
            }
        },
        typeBet(type) {
            switch (type) {
                case "max":
                    this.amount = this.$root.user !== null ? this.$root.user.balance : 0;
                break;
                case "min":
                    this.amount = 1;
                break;
                case "x2":
                    this.amount = (this.amount * 2).toFixed(2);
                break;
                case "/2":
                    this.amount = (this.chance / 2).toFixed(2);
                break;
            }
        },
        typeGoal(type) {
            switch (type) {
                case "max":
                    this.goal = 10000;
                break;
                case "min":
                    this.goal = 1.05;
                break;
                case "x2":
                    this.goal = (this.goal * 2).toFixed(2);
                break;
                case "/2":
                    this.goal = (this.goal / 2).toFixed(2);
                    if(this.goal < 1.05) this.goal = 1.05;
                break;
            }

            this.updateResult('goal');
        },
        typeChance(type) {
            switch (type) {
                case "max":
                    this.chance = 95;
                break;
                case "min":
                    this.chance = 1;
                break;
                case "x2":
                    this.chance = (this.chance * 2).toFixed(2);
                break;
                case "/2":
                    this.chance = (this.chance / 2).toFixed(2);
                break;
            }

            this.updateResult('chance');
        },
        validateBet() {
            this.amount = parseFloat(this.amount).toFixed(2)
        },
        validateChance() {
            this.chance = parseFloat(this.chance).toFixed(2)
        },
        validateGoal() {
            this.goal = parseFloat(this.goal).toFixed(2)
        },
    },
    watch: {
        amount: function() {
            if (this.amount > 1000000) {
                this.amount = 1000000;
            }
        },
        goal: function() {
            if (this.goal > 10000) {
                this.goal = 10000;
            }
        },
        chance: function() {
            if (this.chance > 95) {
                this.chance = 95;
            }
        }
    }
}
</script>

<style scoped>
.bubbles {
    padding: 32px 57px;
    background: #fff;
    border-radius: 0 0 8px 8px;
}

@media (max-width: 62em) {
    .bubbles {
        padding: 12px 15px 23px;
    }
}

.mt-default {
    margin-top: 30px
}

.input__row, .result__row {
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
    justify-content: space-between;
}

.input-item, .result-item {
    display: inline-block;
    width: 30%;
    justify-content: center;
    align-items: center;
}

.flex-30 {
    flex: 0 30%;
}

.flex-65 {
    flex: 0 65%;
}

@media (max-width: 32em) {
    .flex-30, .flex-65 {
        flex: 0 100%;
    }

    .flex-65 {
        margin-top: 10px;
    }

    .input-item:nth-child(1), .input-item:nth-child(2) {
        width: 45%
    }

    .input-item:nth-child(3) {
        margin-top: 18px;
        width: 100%
    }
}

.bubbles__group {
    display: flex;
    flex-wrap: wrap;
    border: 1px solid #6f7cad;
    border-radius: 0 0 6px 6px;
    justify-content: space-between;
    width: 100%;
}

.bubbles__label {
    font-size: 13px;
    line-height: 15px;
    text-align: center;
    letter-spacing: 0.03em;
    display: inline-block;
    color: #b6b0d7;
    margin-bottom: 6px;
    text-transform: uppercase;
}

.bubbles__label_normal {
    text-transform: none;
    font-size: 16px;
    line-height: 25px;
}

.bubbles__amount {
    font-weight: 400;
    font-size: 25px;
    font-family: "Rubik";
    color: #2c3034;
    border: none;
    border-bottom: 1px solid #6f7cad;
    flex: 0 0 100%;
    line-height: 52px;
    width: 100%;
}

.bubbles__amount,
.bubbles__btn {
    text-align: center;
    letter-spacing: 0.03em;
}

.bubbles__btn {
    cursor: pointer;
    flex: 1 0 15%;
    font-weight: 700;
    font-size: 12px;
    line-height: 14px;
    background: transparent;
    color: #9fa6c5;
    height: 33px;
    display: flex;
    align-items: center;
    justify-content: center;
    border: none;
    padding: 0;
}

.bubbles__btn + .bubbles__btn {
    border-left: 1px solid #6f7cad;
}

.btn {
    border-radius: 3px;
    font-size: 14px;
    line-height: 16px;
    text-align: center;
    letter-spacing: 0.03em;
    color: #fff;
    padding: 15px 0;
    width: 100%;
    border: none;
    cursor: pointer;
    user-select: none;
}

.bubbles__btn-range {
    background: #7987a1;
    text-transform: uppercase
}

.bubbles__btn-success {
    background: linear-gradient(90deg, #0cbf88, #12ca56)!important;
}

.bubbles__btn-danger {
    background: linear-gradient(to left, #F45C43, #EB3349)!important;
}

.bubbles__btn-danger, .bubbles__btn-success {
    pointer-events: none
}

.text-coeff {
    font-weight: 700;
}

.m-auto {
    margin: auto
}

.btn-icon {
    width: 12px;
    height: 12px;
    margin-top: 2px;
}
</style>
